# opencv-python 라이브러리 설치
# 설치 명령: pip install opencv-python
import cv2  # OpenCV 라이브러리 임포트

# DroidCam 스트림 URL 설정
ip_address = '192.168.0.9'  # DroidCam 앱에서 제공하는 IP 주소를 입력
port = '4747'  # DroidCam의 기본 포트 번호 (앱에서 확인 가능)
video_url = f'http://{ip_address}:{port}/video'  # DroidCam의 영상 스트림 URL 생성

# OpenCV를 사용하여 스트림 열기
cap = cv2.VideoCapture(video_url)  # 지정된 URL에서 비디오 스트림을 읽어오기

# 스트림이 열렸는지 확인
if not cap.isOpened():  # 스트림을 성공적으로 열지 못한 경우
    print("스트림을 열 수 없습니다.")  # 오류 메시지 출력
    exit()  # 프로그램 종료

# 프레임을 지속적으로 읽어오기
while cap.isOpened():  # 스트림이 열려 있는 동안 반복 실행
    # 프레임 읽기
    ret, frame = cap.read()  # 비디오 스트림에서 한 프레임 읽기
    if ret:  # 프레임을 성공적으로 읽은 경우
        # 프레임을 화면에 표시
        cv2.imshow('DroidCam Video', frame)  # 'DroidCam Video'라는 창에 프레임 출력
    else:  # 프레임 읽기에 실패한 경우
        print("프레임을 읽을 수 없습니다.")  # 오류 메시지 출력
        break  # 루프 종료

    # 키보드 입력을 기다림 ('q' 키를 누르면 종료)
    # cv2.waitKey(1): 1밀리초 동안 키 입력 대기
    if cv2.waitKey(1) == ord('q'):  # 'q' 키가 입력된 경우
        break  # 루프 종료

# 자원 해제
cap.release()  # 비디오 스트림 자원 해제
cv2.destroyAllWindows()  # 모든 OpenCV 창 닫기
