# bleak 라이브러리 설치
# 설치 명령어: pip install bleak
import asyncio  # Python의 비동기 처리를 위한 내장 라이브러리
from bleak import BleakScanner  # Bleak 라이브러리에서 BLE 장치 스캔을 위한 모듈


# 주변 BLE(Bluetooth Low Energy) 장치를 스캔하는 함수 정의
# 비동기 호출을 동기적으로 처리하여 사용자가 쉽게 호출 가능하게 함
def scan_ble_devices_sync():
    """
    주변 BLE 장치를 스캔하고 결과를 출력하는 동기식 함수.

    BLE 장치 스캔은 본질적으로 비동기 작업이지만, 이 함수는 Python의
    이벤트 루프를 생성하여 동기적으로 처리합니다.
    """
    # 비동기 작업을 처리하기 위해 새로운 이벤트 루프 생성
    loop = asyncio.new_event_loop()  # 기존 루프와 독립적으로 작동
    # 새 이벤트 루프를 현재 실행 중인 이벤트 루프로 설정
    asyncio.set_event_loop(loop)

    # BleakScanner.discover(): 비동기로 주변 BLE 장치를 스캔
    # run_until_complete(): 비동기 함수를 동기적으로 실행
    devices = loop.run_until_complete(BleakScanner.discover())

    # 이벤트 루프를 닫아 리소스를 정리
    loop.close()

    # 스캔된 장치 목록 출력
    # Bleak의 discover() 함수는 BLEDevice 객체의 리스트를 반환
    for device in devices:
        # 각 BLEDevice 객체는 다음 정보를 포함:
        # - address: BLE 장치의 MAC 주소
        # - name: BLE 장치 이름 (알 수 없는 경우 None)
        # - rssi: 신호 강도 (dBm 단위, 음수 값)
        print(device)


# 동기식 함수 호출
# 주변 BLE 장치를 스캔하고 결과를 출력
scan_ble_devices_sync()
