# bleak 라이브러리 설치
import asyncio
from bleak import BleakClient

# keyboard 라이브러리 설치
import keyboard  # 숫자키 입력을 감지하기 위한 라이브러리

# HM-10의 BLE 장치 MAC 주소
address = "18:93:D7:33:21:74"  # HM-10 모듈의 MAC 주소 입력22152

# HM-10 모듈에서 제어 명령을 전송할 특성(UUID)
CHARACTERISTIC_UUID = "0000ffe1-0000-1000-8000-00805f9b34fb"

# 자동차 제어 명령
commands = {
    '0': '0',
    '1': '1',
    '2': '2',
    '3': '3',
    '4': '4',
    '5': '5',
    '6': '6',
    '7': '7',
    '8': '8',
    '9': '9',
    '-': '*',
    '+': '#'
}

# HM-10 BLE 모듈에 명령을 전송하는 함수
def send_command_sync(client, key):
    command = commands.get(key)
    if command:
        loop = asyncio.get_event_loop()
        loop.run_until_complete(client.write_gatt_char(CHARACTERISTIC_UUID, command.encode('utf-8')))
        print(f"'{command}' 명령 전송 완료")
    else:
        print("유효하지 않은 명령입니다.")

# 키 입력 감지 및 명령 전송 루프
def control_car_sync():
    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    client = BleakClient(address)
    # loop.run_until_complete를 사용하여 BLE와의 비동기 통신을 동기적으로 처리
    loop.run_until_complete(client.connect())

    if client.is_connected:
        print(f"HM-10 ({address}) 연결 성공!")

        try:
            while True:
                # 숫자키 입력 감지 및 명령 전송
                for key in commands.keys():
                    if keyboard.is_pressed(key):
                        send_command_sync(client, key)

                # 종료를 위해 'q' 키를 누르면 제어 루프 종료
                if keyboard.is_pressed('q'):
                    print("프로그램을 종료합니다.")
                    break

        finally:
            # 종료 시 BLE 연결 해제
            loop.run_until_complete(client.disconnect())
            loop.close()
    else:
        print(f"HM-10 ({address})에 연결할 수 없습니다.")

# 메인 실행 루프 (동기식으로 실행)
control_car_sync()